declare class Writer<T> {
    write(operation: DiffOperation): void;
    close(): T;
}

type DiffToken = {
    value: string;
    start: number;
    end: number;
};
type DiffOperation = {
    type: "equal";
    tokens: DiffToken[];
} | {
    type: "insert";
    tokens: DiffToken[];
} | {
    type: "delete";
    tokens: DiffToken[];
};
declare function diffTokens<TWriter extends Writer<unknown> = ArrayWriter>({ a, b, writer, }: {
    a: {
        tokens: DiffToken[];
        indentType: string;
        indentAmount: number;
    };
    b: {
        tokens: DiffToken[];
        indentType: string;
        indentAmount: number;
    };
    writer?: TWriter;
}): ReturnType<TWriter["close"]>;

declare class ArrayWriter extends Writer<Array<DiffOperation>> {
    private operations;
    write(operation: DiffOperation): void;
    close(): DiffOperation[];
}
declare function diffArrayToString(diffArray: Array<DiffOperation>, options?: {
    omit?: Array<"insert" | "delete" | "equal">;
    insertTagOpen?: string;
    insertTagClose?: string;
    deleteTagOpen?: string;
    deleteTagClose?: string;
    equalTagOpen?: string;
    equalTagClose?: string;
}): string;
declare function diffStringToArray(diffString: string, options?: {
    insertTagOpen?: string;
    insertTagClose?: string;
    deleteTagOpen?: string;
    deleteTagClose?: string;
    equalTagOpen?: string;
    equalTagClose?: string;
}): DiffOperation[];

declare function tokenize({ content, language, }: {
    content: string;
    language: string;
}): {
    tokens: {
        value: string;
        start: number;
        end: number;
    }[];
    indentType: string;
    indentAmount: number;
};

declare class ReadableStreamWriter extends Writer<ReadableStream<DiffOperation>> {
    private stream;
    private controller;
    constructor();
    write(operation: DiffOperation): void;
    close(): ReadableStream<DiffOperation>;
}
declare function diffStreamToTextStream(diffStream: ReadableStream<DiffOperation>, options?: {
    omit?: Array<"insert" | "delete" | "equal">;
    insertTagOpen?: string;
    insertTagClose?: string;
    deleteTagOpen?: string;
    deleteTagClose?: string;
    equalTagOpen?: string;
    equalTagClose?: string;
}): ReadableStream<Uint8Array>;
declare function diffStreamToString(diffStream: ReadableStream<DiffOperation>, options?: {
    omit?: Array<"insert" | "delete" | "equal">;
    insertTagOpen?: string;
    insertTagClose?: string;
    deleteTagOpen?: string;
    deleteTagClose?: string;
    equalTagOpen?: string;
    equalTagClose?: string;
}): Promise<string>;

export { ArrayWriter, type DiffOperation, type DiffToken, ReadableStreamWriter, diffArrayToString, diffStreamToString, diffStreamToTextStream, diffStringToArray, diffTokens, tokenize };
